@@ -9,7 +9,7 @@ use Plack::Util::Accessor qw( content_type expires );
 use HTTP::Status qw//;
 use HTTP::Date;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub calc_expires {
     my ( $expires, $modified, $access ) = @_;
@@ -91,11 +91,15 @@ sub call {
         return if ! defined $type;
         my $type_check;
         for ( @type_match ) {
-            if ( ref $_ && ref $_ eq 'Regexp' ) {
-                if ( $type =~ m!$_! ) {
+            if (my $ref = ref $_) {
+                if ($ref eq 'Regexp' && $type =~ m!$_!) {
                     $type_check = 1;
                     last;
                 }
+                elsif ($ref eq 'CODE') {
+                    $type_check = $_->($env);
+                    last;
+                }
             }
             else {
                 if ( lc $type eq lc $_ ) {
@@ -162,6 +166,11 @@ Note: Expires works only for successful response and If exists Expires HTTP head
 
 Content-Type header to apply Expires
 
+also C<content_type> accept CodeRef
+
+  content_type => sub { my $env = shift; return 1 if $env->{..} }
+
+
 =item Expires
 
 Same format as the Apache mod_expires
